@@ -10,9 +10,6 @@
 
 #undef CHROOT_INPUT_DIR
 
-#undef HAVE_STRSTREAM_H
-#undef HAVE_STRSTREA_H
-
 @BOTTOM@
 
 #include "cxxconfig.h"
