@@ -36,15 +36,14 @@
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif // HAVE_CONFIG_H
 
-#ifdef HAVE_STRSTREAM_H
-#include <strstream.h>
+#ifdef HAVE_SSTREAM
+#include <sstream>
 #else
-#ifdef HAVE_STRSTREA_H
-#include <strstrea.h>
-#endif // HAVE_STRSTREA_H
-#endif // HAVE_STRSTREAM_H
+#include "includes/sstream"
+#endif
+
+#endif // HAVE_CONFIG_H
 
 #include "tags.h"
 #include "colors.h"
@@ -133,8 +132,8 @@ static const short yyrhs[] = {    11,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-    73,    75,    76,    79,    84,    91,    92,    95,    96,    97,
-    98
+    72,    74,    75,    78,    83,    90,    91,    94,    95,    96,
+    97
 };
 #endif
 
@@ -1012,7 +1011,12 @@ parseTags()
     return ;
   }
 
-  printMessage( "Parsing tags.j2h file ...", cerr ) ;
+  printMessage_noln( "Parsing ", cerr ) ;
+  if (tags_file)
+    printMessage_noln (tags_file, cerr);
+  else
+    printMessage_noln (TAGS_FILE, cerr);
+  printMessage( " file ...", cerr ) ;
   opsc_parse() ;
   printMessage( "Parsing done!", cerr ) ;
 }
@@ -1043,9 +1047,11 @@ openTagsFile()
   return file ;
 }
 
-void opsc_error( char *s ) {
-  strstream str ;
-  str << "*** " << s << " on option # " << line << ends ;
-  printError( str.str(), cerr ) ;
+void 
+opsc_error( char *s ) 
+{
+  ostringstream str ;
+  str << "*** " << s << " on option # " << line; 
+  printError( str.str().c_str(), cerr ) ;
   printError( "Using default tags...", cerr ) ;
 }
